pub struct PhoneNumber(pub Option<PhoneNumber>);Expand description
A phone number.
Tuple Fields
0: Option<PhoneNumber>Methods from Deref<Target = Option<PhoneNumber>>
1.0.0 · Sourcepub fn as_ref(&self) -> Option<&T>
pub fn as_ref(&self) -> Option<&T>
Converts from &Option<T> to Option<&T>.
Examples
Calculates the length of an Option<String> as an Option<usize>
without moving the String. The map method takes the self argument by value,
consuming the original, so this technique uses as_ref to first take an Option to a
reference to the value inside the original.
let text: Option<String> = Some("Hello, world!".to_string());
// First, cast `Option<String>` to `Option<&String>` with `as_ref`,
// then consume *that* with `map`, leaving `text` on the stack.
let text_length: Option<usize> = text.as_ref().map(|s| s.len());
println!("still can print text: {text:?}");1.75.0 · Sourcepub fn as_slice(&self) -> &[T]
pub fn as_slice(&self) -> &[T]
Returns a slice of the contained value, if any. If this is None, an
empty slice is returned. This can be useful to have a single type of
iterator over an Option or slice.
Note: Should you have an Option<&T> and wish to get a slice of T,
you can unpack it via opt.map_or(&[], std::slice::from_ref).
Examples
assert_eq!(
[Some(1234).as_slice(), None.as_slice()],
[&[1234][..], &[][..]],
);The inverse of this function is (discounting
borrowing) [_]::first:
for i in [Some(1234_u16), None] {
assert_eq!(i.as_ref(), i.as_slice().first());
}1.40.0 · Sourcepub fn as_deref(&self) -> Option<&<T as Deref>::Target>where
T: Deref,
pub fn as_deref(&self) -> Option<&<T as Deref>::Target>where
T: Deref,
Converts from Option<T> (or &Option<T>) to Option<&T::Target>.
Leaves the original Option in-place, creating a new one with a reference
to the original one, additionally coercing the contents via Deref.
Examples
let x: Option<String> = Some("hey".to_owned());
assert_eq!(x.as_deref(), Some("hey"));
let x: Option<String> = None;
assert_eq!(x.as_deref(), None);Trait Implementations
Sourceimpl AsRef<Option<PhoneNumber>> for PhoneNumber
impl AsRef<Option<PhoneNumber>> for PhoneNumber
Sourcefn as_ref(&self) -> &Option<PhoneNumber>
fn as_ref(&self) -> &Option<PhoneNumber>
Sourceimpl Clone for PhoneNumber
impl Clone for PhoneNumber
Sourcefn clone(&self) -> PhoneNumber
fn clone(&self) -> PhoneNumber
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PhoneNumber
impl Debug for PhoneNumber
Sourceimpl Default for PhoneNumber
impl Default for PhoneNumber
Sourcefn default() -> PhoneNumber
fn default() -> PhoneNumber
Sourceimpl Deref for PhoneNumber
impl Deref for PhoneNumber
Sourceimpl<'de> Deserialize<'de> for PhoneNumber
impl<'de> Deserialize<'de> for PhoneNumber
Sourcefn deserialize<D>(deserializer: D) -> Result<PhoneNumber, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<PhoneNumber, D::Error>where
D: Deserializer<'de>,
Sourceimpl Display for PhoneNumber
impl Display for PhoneNumber
Sourceimpl From<PhoneNumber> for PhoneNumber
impl From<PhoneNumber> for PhoneNumber
Sourcefn from(id: PhoneNumber) -> PhoneNumber
fn from(id: PhoneNumber) -> PhoneNumber
Sourceimpl FromStr for PhoneNumber
impl FromStr for PhoneNumber
Sourceimpl Hash for PhoneNumber
impl Hash for PhoneNumber
Sourceimpl JsonSchema for PhoneNumber
impl JsonSchema for PhoneNumber
Sourcefn schema_name() -> String
fn schema_name() -> String
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
$ref keyword. Read moreSourceimpl PartialEq for PhoneNumber
impl PartialEq for PhoneNumber
Sourceimpl Serialize for PhoneNumber
impl Serialize for PhoneNumber
impl Eq for PhoneNumber
impl StructuralPartialEq for PhoneNumber