Struct front_api::types::ListOfSignaturesApplicationJson
source · [−]pub struct ListOfSignaturesApplicationJson {
pub pagination: Option<Pagination>,
pub underscore_links: Option<ListOfSignaturesApplicationJsonUnderscoreLinks>,
pub results: Option<Vec<SignatureResponse>>,
}Fields
pagination: Option<Pagination>underscore_links: Option<ListOfSignaturesApplicationJsonUnderscoreLinks>results: Option<Vec<SignatureResponse>>Trait Implementations
sourceimpl Clone for ListOfSignaturesApplicationJson
impl Clone for ListOfSignaturesApplicationJson
sourcefn clone(&self) -> ListOfSignaturesApplicationJson
fn clone(&self) -> ListOfSignaturesApplicationJson
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl<'de> Deserialize<'de> for ListOfSignaturesApplicationJson
impl<'de> Deserialize<'de> for ListOfSignaturesApplicationJson
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl JsonSchema for ListOfSignaturesApplicationJson
impl JsonSchema for ListOfSignaturesApplicationJson
sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the $ref keyword. Read more
sourceimpl PartialEq<ListOfSignaturesApplicationJson> for ListOfSignaturesApplicationJson
impl PartialEq<ListOfSignaturesApplicationJson> for ListOfSignaturesApplicationJson
sourcefn eq(&self, other: &ListOfSignaturesApplicationJson) -> bool
fn eq(&self, other: &ListOfSignaturesApplicationJson) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &ListOfSignaturesApplicationJson) -> bool
fn ne(&self, other: &ListOfSignaturesApplicationJson) -> bool
This method tests for !=.
sourceimpl Tabled for ListOfSignaturesApplicationJson
impl Tabled for ListOfSignaturesApplicationJson
impl StructuralPartialEq for ListOfSignaturesApplicationJson