pub struct ListTeammateFoldersResponse {
pub pagination: Option<Pagination>,
pub underscore_links: Option<ListTeammateFoldersResponseUnderscoreLinks>,
pub results: Option<Vec<MessageTemplateResponse>>,
}Fields
pagination: Option<Pagination>underscore_links: Option<ListTeammateFoldersResponseUnderscoreLinks>results: Option<Vec<MessageTemplateResponse>>Trait Implementations
Sourceimpl Clone for ListTeammateFoldersResponse
impl Clone for ListTeammateFoldersResponse
Sourcefn clone(&self) -> ListTeammateFoldersResponse
fn clone(&self) -> ListTeammateFoldersResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListTeammateFoldersResponse
impl Debug for ListTeammateFoldersResponse
Sourceimpl<'de> Deserialize<'de> for ListTeammateFoldersResponse
impl<'de> Deserialize<'de> for ListTeammateFoldersResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListTeammateFoldersResponse
impl JsonSchema for ListTeammateFoldersResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ListTeammateFoldersResponse
impl PartialEq for ListTeammateFoldersResponse
Sourcefn eq(&self, other: &ListTeammateFoldersResponse) -> bool
fn eq(&self, other: &ListTeammateFoldersResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Tabled for ListTeammateFoldersResponse
impl Tabled for ListTeammateFoldersResponse
impl StructuralPartialEq for ListTeammateFoldersResponse